@@ -3,7 +3,7 @@ from selenium.webdriver.chrome.options import Options
 from selenium.webdriver.common.keys import Keys
 from selenium.common.exceptions import NoSuchElementException
 from time import sleep, strftime
-from random import randint,uniform
+from random import randint,uniform,shuffle
 from datetime import datetime,timedelta
 from sys import exit, exc_info, argv
 from re import sub, search
@@ -29,30 +29,46 @@ class Client:
             sys.exit()
         if not self.password:
             print ("Config is missing 'password'")
-            sys.exit()
-        self.hashtag_list = config.get("hashtag_list","photos")
-        self.current_hashtag = None
-        self.path = config.get("path", os.getcwd()) + "/"
-        self.debug = config.get("debug", False)
-        self.follow_profiles_list = config.get("follow_profiles", None)
-        self.chromedriver_path = config.get("chromedriver_path", "/usr/lib/chromium-browser/chromedriver")
-        self.likes_max = config.get("likes", 15)
-        self.watch_stories_minutes = config.get("watch_stories_minutes", 5)
-        self.follows_max = config.get("follow", 0)
-        self.unfollows_max = config.get("unfollow", 0)
-        self.wait_between = config.get("wait_between_runs", 2)
-        self.api = config.get("api", False)
+            sys.exit()       
+        
+        #api settings
+        self.api_key = config.get("api_key", False)
+        self.api_endpoint = config.get("api_endpoint", False);
+         
+        
+        #get settings from api endpoint
+        config_api = {}
+        if self.api_key and self.api_endpoint:
+            response = requests.get(url = self.api_endpoint + "/get", params = {"q":self.api_key})
+            if response.status_code == 200:
+                config_api = response.json();
+        #initialize confing
+        self.parse_config(config, config_api)
+        
+        #run information
         self.likes = 0
-        self.give_likes_when = config.get("give_likes_when", 0)
         self.follows = 0
         self.follow_recent_liked = 0
         self.unfollows = 0
+        self.current_hashtag = None
+        self.stories_watched = 0
         self.start = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
         self.page_height = 400
         self.profiles_pp = 6
         self.home_screen_likes = 0
         self.followers_count = 0
+        self.following_count = 0
+
+
         self.file_name_time_pattern = datetime.now().strftime("%Y-%m-%d %H")
+       
+
+        
+        
+        
+        
+        
+        
         self.css_selectors = {
             "home_feed_username":"> header > div.o-MQd.z8cbW > div.RqtMr > div > span > a",
             "home_feed_like_button":"> div.eo2As > section.ltpMr.Slqrh > span.fr66n > button",
@@ -61,6 +77,7 @@ class Client:
             "unfollow_dialog": "#react-root > section > main > div > header > section > ul > li:nth-child(3) > a",
             "follow_dialog":"#react-root > section > main > div > header > section > ul > li:nth-child(2) > a > span",
             "followers_count":"#react-root > section > main > div > header > section > ul > li:nth-child(2) > a > span",
+            "following_count":"#react-root > section > main > div > header > section > ul > li:nth-child(3) > a > span",
             "flw_button_zero_scroll":"div div:nth-child(3) button",#follow button
             "flw_button_nonzero_scroll":"div.Pkbci button",
             "flw_profile_name_zero_scroll":"div div:nth-child(2) a",#profile name
@@ -101,6 +118,44 @@ class Client:
             self.wd.maximize_window()
             self.open_session()
             self.run()
+    def parse_config (self, config, config_api):
+        self.hashtag_list = config_api.get("hashtags", config.get("hashtags", "instagram,photos")).split(",")
+        shuffle(self.hashtag_list)
+        self.give_likes_when = int(config_api.get("like_if", config.get("like_if", 0)))
+        self.path = config.get("path", os.getcwd()) + "/"
+        self.debug = config.get("debug", False)
+        self.follow_profiles_list = config_api.get("follow_followers_of", config.get("follow_followers_of", None))
+        self.chromedriver_path = config.get("chromedriver_path", "/usr/lib/chromium-browser/chromedriver")
+       
+        #max likes
+        self.likes_max = config_api.get("likes", config.get("likes", 15)).split("-")
+        
+        if len(self.likes_max) == 2:
+            self.likes_max = randint(int(self.likes_max[0].strip()),int(self.likes_max[1].strip()))
+        else:
+            self.likes_max = int(self.likes_max[0].strip())
+        #stories
+        self.watch_stories_minutes = int(config_api.get("watch_stories",config.get("watch_stories", 5)))
+        
+        #follows max
+        self.follows_max = config_api.get("follows", config.get("follows", 0)).split("-")
+        if len(self.follows_max) == 2:
+            self.follows_max = randint(int(self.follows_max[0].strip()),int(self.follows_max[1].strip()))
+        else:
+            self.follows_max = int(self.follows_max[0].strip())
+
+        #unfollows max
+        self.unfollows_max = config_api.get("unfollows", config.get("unfollows", 0))
+        if len(self.unfollows_max) == 2:
+            self.unfollows_max = randint(int(self.unfollows_max[0].strip()),int(self.unfollows_max[1].strip()))
+        else:
+            self.unfollows_max = int(self.unfollows_max[0].strip())
+        
+        self.wait_between = int(config_api.get("between_runs", config.get("between_runs" , 2)))
+        self.run_between = config_api.get("run_between", config.get("run_between" , 0))
+        
+
+        
     def get_popup(self):
         for i in range(len(self.css_selectors.get("home_feed_popups"))):
             try:
@@ -497,6 +552,7 @@ class Client:
             self.log("[watch_stories]   first_url:"+ self.wd.current_url)
             for _ in range(self.watch_stories_minutes):
                 sleep(60)
+                self.stories_watched +=1
                 self.log("[watch_stories]   url_after_sleep=" + self.wd.current_url)
                 if not "stories" in self.wd.current_url:
                     break
@@ -561,20 +617,24 @@ class Client:
         if not os.path.exists(directory):
             os.makedirs(directory)
         return
-    def set_followers_count (self):
+    def set_follow_stats (self):
         try:
             self.navigate_to('https://www.instagram.com/' + self.user)
             followers_count =  self.wd.find_element_by_css_selector(self.css_selectors.get("followers_count")).text
             self.followers_count = followers_count.replace(",","")
+            
+            following_count =  self.wd.find_element_by_css_selector(self.css_selectors.get("following_count")).text
+            self.following_count = following_count.replace(",","")
+            
+        
         except:
             self.parse_error("[get_followers_count] [" + str(exc_info()[0]) + "] " + str(exc_info()[1]))
 
     def send_data(self):
-        URL = "https://daboi.memews.com/sys/write.php"
-        if not self.api:
+        if not self.api_key or not self.api_endpoint:
             return
-        PARAMS = {"q":self.api, "data": self.start +"," + self.end + "," + str(self.followers_count) + "," + str(self.home_screen_likes + self.likes) + "," + str(self.follows + self.follow_recent_liked) + "," + str(self.unfollows) + ",11"}
-        r = requests.get(url = URL,params = PARAMS)
+        PARAMS = {"q":self.api_key, "data": self.start +"," + self.end + "," + str(self.followers_count) + "," + str(self.following_count) + "," +  str(self.likes) + "," + str(self.home_screen_likes) + "," + str(self.follows + self.follow_recent_liked) + "," + str(self.unfollows) + "," + str(self.stories_watched)}
+        r = requests.get(url = self.api_endpoint + "/write",params = PARAMS)
 
     def run (self):
         try:
@@ -582,7 +642,7 @@ class Client:
             loop = True
             # reach_max = int(self.likes_max/len(self.hashtag_list)/2)
             # reach_min = int(reach_max/2)
-            self.set_followers_count()
+            self.set_follow_stats()
             #unfollow / follow profiles 
             self.handle_followers("unfollow")
             self.handle_followers("follow")
@@ -608,7 +668,7 @@ class Client:
                     if loop_num == 0:
                         #watch hashtag stories
                         self.watch_stories(story_type = "hashtag",redirect_to=url)
-                    self.open_hashtag_recent_post(self.current_hashtag)
+                        self.open_hashtag_recent_post(self.current_hashtag)
                     sleep(3)
                     for _ in range(10 + len(self.hashtag_list) - i, 20 + len(self.hashtag_list) - i ):
                         try:
@@ -669,6 +729,6 @@ class Client:
         self.wd.quit()
         self.end = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
         self.send_data()
-        self.print_to_log(message= self.end + ", " + str(self.followers_count) + ", " + str(self.home_screen_likes) + " + " + str(self.likes) + ", " + str(self.follows) + " + " + str(self.follow_recent_liked) + ", " + str(self.unfollows) + "\n", log = 'log')
+        self.print_to_log(message= self.end + ", " + str(self.followers_count) + ", " +  str(self.following_count) + ", " + str(self.home_screen_likes) + " + " + str(self.likes) + ", " + str(self.follows) + " + " + str(self.follow_recent_liked) + ", " + str(self.unfollows) + ", " + str(self.stories_watched) + "\n", log = 'log')
         return
 
